@@ -5,12 +5,17 @@ from __future__ import print_function
 
 from __future__ import absolute_import
 import json
-import geojson
 from threedigrid.admin.pumps.models import Pumps
 from threedigrid.admin import constants
+from threedigrid.geo_utils import raise_import_exception
 from threedigrid.orm.base.encoder import NumpyEncoder
 from six.moves import range
 
+try:
+    import geojson
+except ImportError:
+    geojson = None
+
 
 def format_to_str(value, empty_value='--', format_string='%0.2f'):
     """
@@ -24,6 +29,8 @@ def format_to_str(value, empty_value='--', format_string='%0.2f'):
 
 class PumpsGeoJsonSerializer():
     def __init__(self, pumps=None, data=None, indent=None):
+        if geojson is None:
+            raise_import_exception('geojson')
         if pumps:
             assert isinstance(pumps, Pumps)
         self._data = data
